// -*- mode: C++ -*-

// AUTOGENERATED BY glean_parser.  DO NOT EDIT.

/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_Metrics_h
#define mozilla_Metrics_h

#include "glean/metrictypes.h"

#include <QString>
#include <QObject>


namespace mozilla::glean {
namespace connection_health {
/**
 * generated from connection_health.changed_to_no_signal
 *
 * The connection status changed to no signal.
 * 
 * This event is recorded in both main application and daemon.
 * The logic and cadence of health checks for each of these
 * is not the same.
 * 
 * A no signal event happens when the connection is showing issues,
 * and a silent switch will not address the issue. Or when the connection
 * is showing issues and there have been previous silent switches which
 * did not address the issue.
 */
extern EventMetric changed_to_no_signal;


/**
 * generated from connection_health.changed_to_pending
 *
 * (iOS only) The connection status changed to pending.
 * 
 * This event is recorded in daemon.
 * 
 * Pending status is when the app is first started or when there is
 * no internet.
 */
extern EventMetric changed_to_pending;


/**
 * generated from connection_health.changed_to_stable
 *
 * The connection status changed to stable.
 * 
 * This event is recorded in both main application and daemon.
 * The logic and cadence of health checks for each of these
 * is not the same.
 * 
 * Stable status is when the app is not in a no signal or unstable
 * connection state.
 */
extern EventMetric changed_to_stable;


/**
 * generated from connection_health.changed_to_unstable
 *
 * The connection status changed to unstable.
 * 
 * This event is recorded in both main application and daemon.
 * The logic and cadence of health checks for each of these
 * is not the same.
 * 
 * An unstable event happens when the connection is showing issues,
 * but silent switches may still address the issue.
 */
extern EventMetric changed_to_unstable;


/**
 * generated from connection_health.data_transferred_rx
 *
 * The amount of data received through the VPN tunnel.
 * 
 * This metric is accumulated periodically on a 3hr interval
 * while the VPN is turned on.
 * 
 * This metric is not collected on iOS.
 * 
 * > **Note**: This metric is recorded on the vpnsession ping for
 * > desktop platforms and on the daemonsession ping for mobile platforms.
 */
extern CustomDistributionMetric data_transferred_rx;


/**
 * generated from connection_health.data_transferred_tx
 *
 * The amount of data sent through the VPN tunnel.
 * 
 * This metric is accumulated periodically on a 3hr interval
 * while the VPN is turned on.
 * 
 * This metric is not collected on iOS.
 * 
 * > **Note**: This metric is recorded on the vpnsession ping for
 * > desktop platforms and on the daemonsession ping for mobile platforms.
 */
extern CustomDistributionMetric data_transferred_tx;


/**
 * generated from connection_health.no_signal_count
 *
 * Count of times that the connection health check results
 * in no signal.
 * 
 * The health check counters must not be considered as markers of time.
 * There is a possible situation in the health check (which calls the
 * telemetry) which frequently results in more than one count per second.
 * The situation: A health check is conducted because a network check did not
 * return, and milliseconds later that network check returns and another
 * health check is started because of the return.
 */
extern CounterMetric no_signal_count;


/**
 * generated from connection_health.no_signal_time
 *
 * Time spent in no signal state.
 * 
 * Only collected on desktop for vpnsession, as mobile apps
 * frequently are relaunched during VPN sessions. It is
 * collected in daemonsession for mobile clients.
 */
extern TimingDistributionMetric no_signal_time;


/**
 * generated from connection_health.pending_count
 *
 * (iOS only) Count of times that the connection health check is in pending.
 * 
 * The health check counters must not be considered as markers of time.
 * There is a possible situation in the health check (which calls the
 * telemetry) which frequently results in more than one count per second.
 * The situation: A health check is conducted because a network check did not
 * return, and milliseconds later that network check returns and another
 * health check is started because of the return.
 */
extern CounterMetric pending_count;


/**
 * generated from connection_health.pending_time
 *
 * (iOS only) Time spent in pending state.
 */
extern TimingDistributionMetric pending_time;


/**
 * generated from connection_health.ping_analyzer_error
 *
 * The iOS PingAnalyzer returned an error.
 */
extern EventMetric ping_analyzer_error;

struct PingAnalyzerErrorExtra : EventMetricExtra {
    QVariant _errorMessage = QVariant();

    int __PRIVATE__id = 11;
  };

/**
 * generated from connection_health.stable_count
 *
 * Count of times that the connection health check succeeds.
 * 
 * The health check counters must not be considered as markers of time.
 * There is a possible situation in the health check (which calls the
 * telemetry) which frequently results in more than one count per second.
 * The situation: A health check is conducted because a network check did not
 * return, and milliseconds later that network check returns and another
 * health check is started because of the return.
 */
extern CounterMetric stable_count;


/**
 * generated from connection_health.stable_time
 *
 * Time spent in stable state.
 * 
 * Only collected on desktop for vpnsession, as mobile apps
 * frequently are relaunched during VPN sessions. It is
 * collected in daemonsession for mobile clients.
 */
extern TimingDistributionMetric stable_time;


/**
 * generated from connection_health.unstable_count
 *
 * Count of times that the connection health check results
 * in unstable.
 * 
 * The health check counters must not be considered as markers of time.
 * There is a possible situation in the health check (which calls the
 * telemetry) which frequently results in more than one count per second.
 * The situation: A health check is conducted because a network check did not
 * return, and milliseconds later that network check returns and another
 * health check is started because of the return.
 */
extern CounterMetric unstable_count;


/**
 * generated from connection_health.unstable_time
 *
 * Time spent in unstable state.
 * 
 * Only collected on desktop for vpnsession, as mobile apps
 * frequently are relaunched during VPN sessions. It is
 * collected in daemonsession for mobile clients.
 */
extern TimingDistributionMetric unstable_time;


} // namespace connection_health
namespace performance {
/**
 * generated from performance.time_to_main_screen
 *
 * The time the app took between starting and rendering the main screen.
 */
extern TimingDistributionMetric time_to_main_screen;


} // namespace performance
namespace sample {
/**
 * generated from sample.addon_message_state_changed
 *
 * The addon message' state changed
 */
extern EventMetric addon_message_state_changed;

struct AddonMessageStateChangedExtra : EventMetricExtra {
    QVariant _messageId = QVariant();
    QVariant _messageState = QVariant();

    int __PRIVATE__id = 17;
  };

/**
 * generated from sample.authentication_error
 *
 * The user is shown an error while authenticating in the app.
 */
extern EventMetric authentication_error;

struct AuthenticationErrorExtra : EventMetricExtra {
    QVariant _reason = QVariant();

    int __PRIVATE__id = 18;
  };

/**
 * generated from sample.authentication_failure
 *
 * The authentication flow has terminated with an error
 */
extern EventMetric authentication_failure;


/**
 * generated from sample.authentication_failure_by_geo
 *
 * The authentication flow has terminated with a geo-restriction error
 */
extern EventMetric authentication_failure_by_geo;


/**
 * generated from sample.bottom_navigation_bar_click
 *
 * The user has tapped a bottom navigation bar button.
 */
extern EventMetric bottom_navigation_bar_click;

struct BottomNavigationBarClickExtra : EventMetricExtra {
    QVariant _barButton = QVariant();

    int __PRIVATE__id = 21;
  };

/**
 * generated from sample.delete_account_clicked
 *
 * The user has clicked the “delete account” button from the
 * account deletion view.
 */
extern EventMetric delete_account_clicked;


/**
 * generated from sample.delete_account_requested
 *
 * The user has clicked the “delete account” button from the profile view.
 */
extern EventMetric delete_account_requested;


/**
 * generated from sample.error_alert_shown
 *
 * A generic error alet is shown.
 */
extern EventMetric error_alert_shown;

struct ErrorAlertShownExtra : EventMetricExtra {
    QVariant _filename = QVariant();
    QVariant _linenumber = QVariant();
    QVariant _task = QVariant();

    int __PRIVATE__id = 24;
  };

/**
 * generated from sample.iap_g_billing_not_available
 *
 * The Billing Client was not able to setup itself
 */
extern EventMetric iap_g_billing_not_available;


/**
 * generated from sample.iap_g_launchbillingflow_failed
 *
 * The billing client failed to launch the billing Flow
 */
extern EventMetric iap_g_launchbillingflow_failed;


/**
 * generated from sample.iap_g_no_sku_details
 *
 * There was an attempt to initiate a purchase without an SKU
 */
extern EventMetric iap_g_no_sku_details;


/**
 * generated from sample.iap_g_purchase_ack_failed
 *
 * The billing client failed to acknowledge the purchase
 */
extern EventMetric iap_g_purchase_ack_failed;


/**
 * generated from sample.iap_g_purchases_update_is_null
 *
 * Got a "null" response while fetching purchase updates
 */
extern EventMetric iap_g_purchases_update_is_null;


/**
 * generated from sample.iap_g_purchases_updated_failed
 *
 * Encountered an error while processing incoming purchase updates
 */
extern EventMetric iap_g_purchases_updated_failed;

struct IapGPurchasesUpdatedFailedExtra : EventMetricExtra {
    QVariant _reason = QVariant();

    int __PRIVATE__id = 30;
  };

/**
 * generated from sample.iap_g_query_purchases_failed
 *
 * The billing client failed to fetch purchases
 */
extern EventMetric iap_g_query_purchases_failed;


/**
 * generated from sample.iap_g_query_sku_details_failed
 *
 * The billing client failed to fetch the SkuDetails
 */
extern EventMetric iap_g_query_sku_details_failed;


/**
 * generated from sample.iap_g_sku_without_month
 *
 * Google play did not send a monthCount for a sku
 */
extern EventMetric iap_g_sku_without_month;


/**
 * generated from sample.iap_g_unexpected_purchasestate
 *
 * The client encountered an unexpected non-purchased product
 */
extern EventMetric iap_g_unexpected_purchasestate;


/**
 * generated from sample.user_changed_endpoint_geo
 *
 * User changed the geography (city, or cities if multihop) of the endpoint
 */
extern EventMetric user_changed_endpoint_geo;

struct UserChangedEndpointGeoExtra : EventMetricExtra {
    QVariant _server = QVariant();

    int __PRIVATE__id = 35;
  };

} // namespace sample
namespace session {
/**
 * generated from session.apps_excluded
 *
 * The number of apps the user is excluding from the VPN tunnel
 */
extern QuantityMetric apps_excluded;


/**
 * generated from session.daemon_session_end
 *
 * (Mobile-only) The time the user ends a VPN session from the daemon or
 * network extension
 */
extern DatetimeMetric daemon_session_end;


/**
 * generated from session.daemon_session_id
 *
 * (Mobile-only) A unique identifier for each session.
 * This is used to connect unique VPN sessions across pings, and as a safety
 * check on edge cases of VPN activation/deactivation, such as a session
 * being started/ended from mobile system settings.
 */
extern UuidMetric daemon_session_id;


/**
 * generated from session.daemon_session_source
 *
 * (Mobile-only) Where the VPN session started from, to determine how many
 * sessions start outside the app. Values should be "app" or "system".
 * "system" covers cases like system settings, autostart on boot, tile, etc.
 */
extern StringMetric daemon_session_source;


/**
 * generated from session.daemon_session_start
 *
 * (Mobile-only) The time the user starts a VPN session from the daemon or
 * network extension
 */
extern DatetimeMetric daemon_session_start;


/**
 * generated from session.daemon_silent_server_switch
 *
 * (Mobile only) The daemon requests a silent server switch.
 * 
 * Extra key only included on iOS.
 */
extern EventMetric daemon_silent_server_switch;

struct DaemonSilentServerSwitchExtra : EventMetricExtra {
    QVariant _wasServerAvailable = QVariant();

    int __PRIVATE__id = 41;
  };

/**
 * generated from session.dns_type
 *
 * The type of DNS a user has active:
 * - NoCustomDNSAvailable: Custom DNS app feature isn't available
 * - Default: App's default DNS server
 * - Custom: User has provided a custom valid IP address for their DNS
 * - BlockAds: One of app's privacy DNS options
 * - BlockTrackers: One of app's privacy DNS options
 * - BlockAdsAndTrackers: One of app's privacy DNS options
 * - BlockMalware: One of app's privacy DNS options
 * - BlockMalwareAndAds: One of app's privacy DNS options
 * - BlockMalwareAndTrackers: One of app's privacy DNS options
 * - BlockMalwareAndAdsAndTrackers: One of app's privacy DNS options
 */
extern StringMetric dns_type;


/**
 * generated from session.installation_id
 *
 * A unique identifier to connect the app and daemon Glean instances.
 */
extern UuidMetric installation_id;


/**
 * generated from session.session_end
 *
 * The time the user ends a VPN session from the app
 */
extern DatetimeMetric session_end;


/**
 * generated from session.session_id
 *
 * A unique identifier for each session. This is used to connect unique VPN
 * sessions across pings, and as a safety check on edge cases of VPN
 * activation/deactivation, such as a session being started/ended from mobile
 * system settings.
 */
extern UuidMetric session_id;


/**
 * generated from session.session_start
 *
 * The time the user starts a VPN session from the app
 */
extern DatetimeMetric session_start;


} // namespace session
namespace settings {
/**
 * generated from settings.connect_on_startup_active
 *
 * The status of whether the VPN is activated on device start
 */
extern BooleanMetric connect_on_startup_active;


/**
 * generated from settings.using_system_language
 *
 * Status of whether app is being used in language of the operating system
 */
extern BooleanMetric using_system_language;


} // namespace settings
namespace web_authentication {
/**
 * generated from web_authentication.failed
 *
 * Web authentication was unsuccessfully completed.
 */
extern EventMetric failed;

struct FailedExtra : EventMetricExtra {
    QVariant _uuid = QVariant();

    int __PRIVATE__id = 49;
  };

/**
 * generated from web_authentication.started
 *
 * Web authentication was started.
 */
extern EventMetric started;

struct StartedExtra : EventMetricExtra {
    QVariant _uuid = QVariant();

    int __PRIVATE__id = 50;
  };

/**
 * generated from web_authentication.successful
 *
 * Web authentication was successfully completed.
 */
extern EventMetric successful;

struct SuccessfulExtra : EventMetricExtra {
    QVariant _uuid = QVariant();

    int __PRIVATE__id = 51;
  };

} // namespace web_authentication
namespace extension {
/**
 * generated from extension.count_excluded
 *
 * The amount of websites excluded from the VPN
 */
extern QuantityMetric count_excluded;


/**
 * generated from extension.count_geoprefed
 *
 * The amount of Websites with a GeoPrefrence.
 */
extern QuantityMetric count_geoprefed;


/**
 * generated from extension.error_screen
 *
 * The user has just moved on to the main screen
 * i.e. the screen with the VPN toggle button.
 */
extern EventMetric error_screen;

struct ErrorScreenExtra : EventMetricExtra {
    QVariant _error = QVariant();

    int __PRIVATE__id = 54;
  };

/**
 * generated from extension.fx_protection_disabled
 *
 * The user has toggled the Fx Protection Off
 */
extern EventMetric fx_protection_disabled;


/**
 * generated from extension.fx_protection_enabled
 *
 * The user has toggled the Fx Protection On
 */
extern EventMetric fx_protection_enabled;


/**
 * generated from extension.fx_protection_mode_changed
 *
 * The Protection Mode Changed
 */
extern EventMetric fx_protection_mode_changed;

struct FxProtectionModeChangedExtra : EventMetricExtra {
    QVariant _messageState = QVariant();

    int __PRIVATE__id = 57;
  };

/**
 * generated from extension.has_completed_onboarding
 *
 * True if the user has completed onboarding.
 */
extern BooleanMetric has_completed_onboarding;


/**
 * generated from extension.main_screen
 *
 * The user has just moved on to the main screen
 * i.e. the screen with the VPN toggle button.
 */
extern EventMetric main_screen;


/**
 * generated from extension.used_feature_disable_firefox_protection
 *
 * True if the user has disabled the VPN for firefox
 */
extern BooleanMetric used_feature_disable_firefox_protection;


/**
 * generated from extension.used_feature_page_action_revoke_exclude
 *
 * True if the user has removed a Website Exclusion from the Page action
 */
extern BooleanMetric used_feature_page_action_revoke_exclude;


/**
 * generated from extension.used_feature_page_action_revoke_geopref
 *
 * True if the user has removed a Website GeoPrefrence from the Page action
 */
extern BooleanMetric used_feature_page_action_revoke_geopref;


/**
 * generated from extension.used_feature_settings_page
 *
 * True if the user has opened the internal settings page.
 */
extern BooleanMetric used_feature_settings_page;


} // namespace extension
namespace interaction {
/**
 * generated from interaction.about_us_selected
 *
 * The About us button in the Settings screen was selected
 */
extern EventMetric about_us_selected;

struct AboutUsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 64;
  };

/**
 * generated from interaction.account_selected
 *
 * User has clicked on their Account in the Settings screen
 */
extern EventMetric account_selected;

struct AccountSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 65;
  };

/**
 * generated from interaction.add_application_selected
 *
 * The user has clicked on Add application in Excluded Apps
 */
extern EventMetric add_application_selected;

struct AddApplicationSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 66;
  };

/**
 * generated from interaction.add_devices_selected
 *
 * The user has clicked the devices step progress bar button in onboarding
 */
extern EventMetric add_devices_selected;

struct AddDevicesSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 67;
  };

/**
 * generated from interaction.already_a_subscriber_selected
 *
 * The "Already a subscriber" button was clicked.
 */
extern EventMetric already_a_subscriber_selected;

struct AlreadyASubscriberSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 68;
  };

/**
 * generated from interaction.app_exclusions_selected
 *
 * The user has clicked the button that opens
 * the Excluded Apps modal
 */
extern EventMetric app_exclusions_selected;

struct AppExclusionsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 69;
  };

/**
 * generated from interaction.app_preferences_selected
 *
 * The Preferences button in the Settings screen was selected
 */
extern EventMetric app_preferences_selected;

struct AppPreferencesSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 70;
  };

/**
 * generated from interaction.approve_mozilla_vpn_selected
 *
 * The user has clicked approve mozilla vpn in onboarding
 */
extern EventMetric approve_mozilla_vpn_selected;

struct ApproveMozillaVpnSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 71;
  };

/**
 * generated from interaction.back_selected
 *
 * The back arrow button was clicked.
 */
extern EventMetric back_selected;

struct BackSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 72;
  };

/**
 * generated from interaction.block_ads_disabled
 *
 * The user has unchecked the block ads checkbox
 */
extern EventMetric block_ads_disabled;

struct BlockAdsDisabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 73;
  };

/**
 * generated from interaction.block_ads_enabled
 *
 * The user has checked the block ads checkbox
 */
extern EventMetric block_ads_enabled;

struct BlockAdsEnabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 74;
  };

/**
 * generated from interaction.block_malware_disabled
 *
 * The user has unchecked the block malware checkbox
 */
extern EventMetric block_malware_disabled;

struct BlockMalwareDisabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 75;
  };

/**
 * generated from interaction.block_malware_enabled
 *
 * The user has checked the block malware checkbox
 */
extern EventMetric block_malware_enabled;

struct BlockMalwareEnabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 76;
  };

/**
 * generated from interaction.block_trackers_disabled
 *
 * The user has unchecked the block trackers checkbox
 */
extern EventMetric block_trackers_disabled;

struct BlockTrackersDisabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 77;
  };

/**
 * generated from interaction.block_trackers_enabled
 *
 * The user has checked the block trackers checkbox
 */
extern EventMetric block_trackers_enabled;

struct BlockTrackersEnabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 78;
  };

/**
 * generated from interaction.cancel_selected
 *
 * A "cancel" button was clicked.
 */
extern EventMetric cancel_selected;

struct CancelSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 79;
  };

/**
 * generated from interaction.change_email_selected
 *
 * The "Change email" button was clicked.
 */
extern EventMetric change_email_selected;

struct ChangeEmailSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 80;
  };

/**
 * generated from interaction.change_plan_selected
 *
 * The user has clicked the “change plan” button from the subscription management
 * view (monthly web plan)
 */
extern EventMetric change_plan_selected;

struct ChangePlanSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 81;
  };

/**
 * generated from interaction.clear_app_exclusions_selected
 *
 * The user has clicked on Clear all to clear all Excluded Apps
 */
extern EventMetric clear_app_exclusions_selected;

struct ClearAppExclusionsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 82;
  };

/**
 * generated from interaction.close_selected
 *
 * The user has clicked the "X" button that closes modals.
 * 
 * Note: When recorded from the speed test screen, the `screen`
 * extra key may have the value `unexpected`. That value is used
 * if this event is recorded while the speed test modal is closed.
 * Although that is theoretically not possible, the code path for
 * such a situation exists. Large number of this event with this
 * value for the `screen` extra key would mean a bug in the code.
 */
extern EventMetric close_selected;

struct CloseSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 83;
  };

/**
 * generated from interaction.connect_on_startup_disabled
 *
 * The user has disabled connect on startup
 */
extern EventMetric connect_on_startup_disabled;

struct ConnectOnStartupDisabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 84;
  };

/**
 * generated from interaction.connect_on_startup_enabled
 *
 * The user has enabled connect on startup
 */
extern EventMetric connect_on_startup_enabled;

struct ConnectOnStartupEnabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 85;
  };

/**
 * generated from interaction.continue_selected
 *
 * A "Continue" button was clicked
 */
extern EventMetric continue_selected;

struct ContinueSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 86;
  };

/**
 * generated from interaction.create_account_selected
 *
 * The "Create account" button was clicked.
 */
extern EventMetric create_account_selected;

struct CreateAccountSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 87;
  };

/**
 * generated from interaction.data_use_selected
 *
 * The user has clicked the data step progress bar button in onboarding
 */
extern EventMetric data_use_selected;

struct DataUseSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 88;
  };

/**
 * generated from interaction.dns_settings_selected
 *
 * User clicked on DNS settings in Preferences
 */
extern EventMetric dns_settings_selected;

struct DnsSettingsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 89;
  };

/**
 * generated from interaction.edit_selected
 *
 * The user has clicked the "edit account" button
 */
extern EventMetric edit_selected;

struct EditSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 90;
  };

/**
 * generated from interaction.forgot_your_password_selected
 *
 * The "Forgot your password?" button was clicked.
 */
extern EventMetric forgot_your_password_selected;

struct ForgotYourPasswordSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 91;
  };

/**
 * generated from interaction.get_help_selected
 *
 * The "Help" link was clicked.
 */
extern EventMetric get_help_selected;

struct GetHelpSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 92;
  };

/**
 * generated from interaction.get_started_selected
 *
 * The user has clicked get started in onboarding
 */
extern EventMetric get_started_selected;

struct GetStartedSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 93;
  };

/**
 * generated from interaction.go_back_selected
 *
 * A "go back" button was clicked
 */
extern EventMetric go_back_selected;

struct GoBackSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 94;
  };

/**
 * generated from interaction.help_tooltip_selected
 *
 * The user has clicked a help tooltip button
 */
extern EventMetric help_tooltip_selected;

struct HelpTooltipSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 95;
  };

/**
 * generated from interaction.home_selected
 *
 * User has clicked on the Home button
 */
extern EventMetric home_selected;

struct HomeSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 96;
  };

/**
 * generated from interaction.language_selected
 *
 * User clicked on Language in Preferences
 */
extern EventMetric language_selected;

struct LanguageSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 97;
  };

/**
 * generated from interaction.learn_more_selected
 *
 * The user has clicked a learn more link
 */
extern EventMetric learn_more_selected;

struct LearnMoreSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 98;
  };

/**
 * generated from interaction.manage_subscription_selected
 *
 * The user has clicked the “manage subscription” button from the subscription
 * management view
 */
extern EventMetric manage_subscription_selected;

struct ManageSubscriptionSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 99;
  };

/**
 * generated from interaction.messages_selected
 *
 * User has clicked on the Messages button
 */
extern EventMetric messages_selected;

struct MessagesSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 100;
  };

/**
 * generated from interaction.more_privacy_selected
 *
 * The user has clicked the privacy step progress bar button in onboarding
 */
extern EventMetric more_privacy_selected;

struct MorePrivacySelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 101;
  };

/**
 * generated from interaction.my_devices_selected
 *
 * The Devices button in the Settings screen was selected
 */
extern EventMetric my_devices_selected;

struct MyDevicesSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 102;
  };

/**
 * generated from interaction.notifications_selected
 *
 * User clicked on Notifications in Preferences
 */
extern EventMetric notifications_selected;

struct NotificationsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 103;
  };

/**
 * generated from interaction.open_connection_info_selected
 *
 * The user has clicked the button that opens
 * the connection information modal
 */
extern EventMetric open_connection_info_selected;

struct OpenConnectionInfoSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 104;
  };

/**
 * generated from interaction.paste_password_selected
 *
 * The "Paste" button was clicked on the password input.
 */
extern EventMetric paste_password_selected;

struct PastePasswordSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 105;
  };

/**
 * generated from interaction.privacy_features_selected
 *
 * The Privacy features button in the Settings screen was selected
 */
extern EventMetric privacy_features_selected;

struct PrivacyFeaturesSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 106;
  };

/**
 * generated from interaction.privacy_notice_selected
 *
 * The "Privacy notice" button was clicked.
 */
extern EventMetric privacy_notice_selected;

struct PrivacyNoticeSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 107;
  };

/**
 * generated from interaction.resend_code_selected
 *
 * The "Resend code" button was clicked in one of the security code verification
 * screens.
 */
extern EventMetric resend_code_selected;

struct ResendCodeSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 108;
  };

/**
 * generated from interaction.reset_vpn_selected
 *
 * The user has clicked the button to confirm a reset of the VPN settings
 */
extern EventMetric reset_vpn_selected;

struct ResetVpnSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 109;
  };

/**
 * generated from interaction.search_selected
 *
 * The user has clicked on the search field in Excluded Apps
 */
extern EventMetric search_selected;

struct SearchSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 110;
  };

/**
 * generated from interaction.settings_selected
 *
 * User has clicked on the Settings button
 */
extern EventMetric settings_selected;

struct SettingsSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 111;
  };

/**
 * generated from interaction.show_android_qr_selected
 *
 * The user has selected the android segment of the devices toggle in onboarding
 */
extern EventMetric show_android_qr_selected;

struct ShowAndroidQrSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 112;
  };

/**
 * generated from interaction.show_ios_qr_selected
 *
 * The user has selected the android segment of the devices toggle in onboarding
 */
extern EventMetric show_ios_qr_selected;

struct ShowIosQrSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 113;
  };

/**
 * generated from interaction.sign_in_selected
 *
 * A "Sign in" button was clicked.
 */
extern EventMetric sign_in_selected;

struct SignInSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 114;
  };

/**
 * generated from interaction.sign_out_selected
 *
 * The "Sign out" button was clicked.
 */
extern EventMetric sign_out_selected;

struct SignOutSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 115;
  };

/**
 * generated from interaction.signup_selected
 *
 * The "Sign up" button was clicked.
 */
extern EventMetric signup_selected;

struct SignupSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 116;
  };

/**
 * generated from interaction.subscribe_now_selected
 *
 * The "Subscribe now" button was clicked.
 */
extern EventMetric subscribe_now_selected;

struct SubscribeNowSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 117;
  };

/**
 * generated from interaction.terms_of_service_selected
 *
 * The "Terms of Service" button was clicked.
 */
extern EventMetric terms_of_service_selected;

struct TermsOfServiceSelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 118;
  };

/**
 * generated from interaction.verify_selected
 *
 * The "Verify" button was clicked in one of the security code verification
 * screens.
 */
extern EventMetric verify_selected;

struct VerifySelectedExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 119;
  };

/**
 * generated from interaction.vpn_on_startup_disabled
 *
 * Disabled VPN on startup
 */
extern EventMetric vpn_on_startup_disabled;

struct VpnOnStartupDisabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 120;
  };

/**
 * generated from interaction.vpn_on_startup_enabled
 *
 * Enabled VPN on startup
 */
extern EventMetric vpn_on_startup_enabled;

struct VpnOnStartupEnabledExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 121;
  };

} // namespace interaction
namespace impression {
/**
 * generated from impression.account_screen
 *
 * The user has viewed the subscription management screen
 */
extern EventMetric account_screen;

struct AccountScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 122;
  };

/**
 * generated from impression.app_exclusions_info_screen
 *
 * The user has opened the Excluded Apps help sheet
 */
extern EventMetric app_exclusions_info_screen;

struct AppExclusionsInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 123;
  };

/**
 * generated from impression.app_exclusions_screen
 *
 * The user has just moved on to the Excluded Apps screen
 */
extern EventMetric app_exclusions_screen;

struct AppExclusionsScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 124;
  };

/**
 * generated from impression.app_preferences_screen
 *
 * User is on the Preferences screen
 */
extern EventMetric app_preferences_screen;

struct AppPreferencesScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 125;
  };

/**
 * generated from impression.confirming_subscription_screen
 *
 * The user has entered the "Confirming subscription" screen.
 */
extern EventMetric confirming_subscription_screen;

struct ConfirmingSubscriptionScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 126;
  };

/**
 * generated from impression.connect_on_startup_screen
 *
 * The user has viewed the connect on startup onboarding slide.
 */
extern EventMetric connect_on_startup_screen;

struct ConnectOnStartupScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 127;
  };

/**
 * generated from impression.connection_info_screen
 *
 * The user has just moved on to the screen that shows
 * the connection information
 */
extern EventMetric connection_info_screen;

struct ConnectionInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 128;
  };

/**
 * generated from impression.continue_in_browser_screen
 *
 * The user has entered the "Continue in browser" screen.
 */
extern EventMetric continue_in_browser_screen;

struct ContinueInBrowserScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 129;
  };

/**
 * generated from impression.create_password_screen
 *
 * The user has entered the "Create password" screen.
 */
extern EventMetric create_password_screen;

struct CreatePasswordScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 130;
  };

/**
 * generated from impression.data_collection_screen
 *
 * The user has viewed the data collection onboarding slide.
 */
extern EventMetric data_collection_screen;

struct DataCollectionScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 131;
  };

/**
 * generated from impression.dns_settings_info_screen
 *
 * The user has opened the dns settings help sheet
 */
extern EventMetric dns_settings_info_screen;

struct DnsSettingsInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 132;
  };

/**
 * generated from impression.dns_settings_screen
 *
 * User has opened the DNS settings screen
 */
extern EventMetric dns_settings_screen;

struct DnsSettingsScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 133;
  };

/**
 * generated from impression.enter_email_screen
 *
 * The user has entered the "Enter email" screen.
 */
extern EventMetric enter_email_screen;

struct EnterEmailScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 134;
  };

/**
 * generated from impression.enter_password_screen
 *
 * The user has entered the "Enter password" screen.
 */
extern EventMetric enter_password_screen;

struct EnterPasswordScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 135;
  };

/**
 * generated from impression.enter_security_code_screen
 *
 * The user has entered the screen to enter a TOTP security code.
 */
extern EventMetric enter_security_code_screen;

struct EnterSecurityCodeScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 136;
  };

/**
 * generated from impression.enter_unblock_code_screen
 *
 * The user has entered the "Enter unblock code" screen.
 */
extern EventMetric enter_unblock_code_screen;

struct EnterUnblockCodeScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 137;
  };

/**
 * generated from impression.enter_verification_code_screen
 *
 * The user has entered the screen to enter email verification code.
 */
extern EventMetric enter_verification_code_screen;

struct EnterVerificationCodeScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 138;
  };

/**
 * generated from impression.get_more_privacy_screen
 *
 * The user has viewed the get more privacy onboarding slide.
 */
extern EventMetric get_more_privacy_screen;

struct GetMorePrivacyScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 139;
  };

/**
 * generated from impression.help_screen
 *
 * The user has just opened the "Help" screen
 */
extern EventMetric help_screen;

struct HelpScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 140;
  };

/**
 * generated from impression.install_on_5_devices_screen
 *
 * The user has viewed the install on 5 devices onboarding slide.
 */
extern EventMetric install_on_5_devices_screen;

struct InstallOn5DevicesScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 141;
  };

/**
 * generated from impression.language_screen
 *
 * User has opened the Language screen
 */
extern EventMetric language_screen;

struct LanguageScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 142;
  };

/**
 * generated from impression.location_info_screen
 *
 * The user has opened the select location help sheet
 */
extern EventMetric location_info_screen;

struct LocationInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 143;
  };

/**
 * generated from impression.location_multihop_screen
 *
 * The user has opened to the multihop screen
 * 
 * Note: When recorded, the `screen` extra key may have the value
 * `unexpected`. That value is used if this event is recorded
 * when an unexpected segment is clicked (not singlehop or multihop)
 * Although that is theoretically not possible, the code path for
 * such a situation exists. Large number of this event with this
 * value for the `screen` extra key would mean a bug in the code.
 */
extern EventMetric location_multihop_screen;

struct LocationMultihopScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 144;
  };

/**
 * generated from impression.location_singlehop_screen
 *
 * The user has opened to the singlehop screen
 */
extern EventMetric location_singlehop_screen;

struct LocationSinglehopScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 145;
  };

/**
 * generated from impression.main_screen
 *
 * The user has just moved on to the main screen
 * i.e. the screen with the VPN toggle button.
 */
extern EventMetric main_screen;

struct MainScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 146;
  };

/**
 * generated from impression.my_devices_info_screen
 *
 * The user has opened the devices help sheet
 */
extern EventMetric my_devices_info_screen;

struct MyDevicesInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 147;
  };

/**
 * generated from impression.my_devices_screen
 *
 * The user has opened the devices settings
 */
extern EventMetric my_devices_screen;

struct MyDevicesScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 148;
  };

/**
 * generated from impression.network_permissions_screen
 *
 * The user has viewed the grant network permissions onboarding slide.
 */
extern EventMetric network_permissions_screen;

struct NetworkPermissionsScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 149;
  };

/**
 * generated from impression.privacy_features_info_screen
 *
 * The user has opened the privacy features help sheet
 */
extern EventMetric privacy_features_info_screen;

struct PrivacyFeaturesInfoScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 150;
  };

/**
 * generated from impression.privacy_features_screen
 *
 * The user has opened the privacy features settings
 */
extern EventMetric privacy_features_screen;

struct PrivacyFeaturesScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 151;
  };

/**
 * generated from impression.settings_screen
 *
 * The user has just moved on to the settings screen
 */
extern EventMetric settings_screen;

struct SettingsScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 152;
  };

/**
 * generated from impression.signup_screen
 *
 * The user has entered the "Sign up" screen.
 */
extern EventMetric signup_screen;

struct SignupScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 153;
  };

/**
 * generated from impression.subscription_needed_screen
 *
 * The user has entered the "Subscription needed" screen.
 */
extern EventMetric subscription_needed_screen;

struct SubscriptionNeededScreenExtra : EventMetricExtra {
    QVariant _screen = QVariant();

    int __PRIVATE__id = 154;
  };

} // namespace impression
namespace outcome {
/**
 * generated from outcome.login_ended
 *
 * The user has just completed the login process.
 */
extern EventMetric login_ended;


/**
 * generated from outcome.login_started
 *
 * The user has started the login process.
 */
extern EventMetric login_started;


/**
 * generated from outcome.onboarding_completed
 *
 * The user has just completed the onboarding experience
 */
extern EventMetric onboarding_completed;


/**
 * generated from outcome.onboarding_ntwrk_perm_denied
 *
 * The user has denied the VPN configuration to be created on the system
 */
extern EventMetric onboarding_ntwrk_perm_denied;


/**
 * generated from outcome.onboarding_ntwrk_perm_granted
 *
 * The user has allowed the VPN configuration to be created on the system
 */
extern EventMetric onboarding_ntwrk_perm_granted;


/**
 * generated from outcome.onboarding_started
 *
 * The user has just started the onboarding experience for the first time
 */
extern EventMetric onboarding_started;


/**
 * generated from outcome.registration_completed
 *
 * The user has just completed the registration process.
 */
extern EventMetric registration_completed;


/**
 * generated from outcome.registration_started
 *
 * The user has started the registration process.
 */
extern EventMetric registration_started;


/**
 * generated from outcome.subscription_completed
 *
 * The user has just completed the subscription process.
 */
extern EventMetric subscription_completed;


/**
 * generated from outcome.subscription_failed
 *
 * The subscription process has errored.
 */
extern EventMetric subscription_failed;

struct SubscriptionFailedExtra : EventMetricExtra {
    QVariant _reason = QVariant();

    int __PRIVATE__id = 164;
  };

/**
 * generated from outcome.subscription_started
 *
 * The user has just started the subscription process.
 */
extern EventMetric subscription_started;


/**
 * generated from outcome.two_fa_verification_failed
 *
 * The user has just failed the 2FA process.
 */
extern EventMetric two_fa_verification_failed;

struct TwoFaVerificationFailedExtra : EventMetricExtra {
    QVariant _type = QVariant();

    int __PRIVATE__id = 166;
  };

/**
 * generated from outcome.two_fa_verification_succeeded
 *
 * The user has just succeeded in the 2FA process.
 */
extern EventMetric two_fa_verification_succeeded;

struct TwoFaVerificationSucceededExtra : EventMetricExtra {
    QVariant _type = QVariant();

    int __PRIVATE__id = 167;
  };

} // namespace outcome
} // namespace mozilla::glean

class __DONOTUSE__ConnectionHealth final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* changedToNoSignal READ changedToNoSignalGetter CONSTANT);
  Q_PROPERTY(EventMetric* changedToPending READ changedToPendingGetter CONSTANT);
  Q_PROPERTY(EventMetric* changedToStable READ changedToStableGetter CONSTANT);
  Q_PROPERTY(EventMetric* changedToUnstable READ changedToUnstableGetter CONSTANT);
  Q_PROPERTY(CustomDistributionMetric* dataTransferredRx READ dataTransferredRxGetter CONSTANT);
  Q_PROPERTY(CustomDistributionMetric* dataTransferredTx READ dataTransferredTxGetter CONSTANT);
  Q_PROPERTY(CounterMetric* noSignalCount READ noSignalCountGetter CONSTANT);
  Q_PROPERTY(TimingDistributionMetric* noSignalTime READ noSignalTimeGetter CONSTANT);
  Q_PROPERTY(CounterMetric* pendingCount READ pendingCountGetter CONSTANT);
  Q_PROPERTY(TimingDistributionMetric* pendingTime READ pendingTimeGetter CONSTANT);
  Q_PROPERTY(EventMetric* pingAnalyzerError READ pingAnalyzerErrorGetter CONSTANT);
  Q_PROPERTY(CounterMetric* stableCount READ stableCountGetter CONSTANT);
  Q_PROPERTY(TimingDistributionMetric* stableTime READ stableTimeGetter CONSTANT);
  Q_PROPERTY(CounterMetric* unstableCount READ unstableCountGetter CONSTANT);
  Q_PROPERTY(TimingDistributionMetric* unstableTime READ unstableTimeGetter CONSTANT);

  public:
    __DONOTUSE__ConnectionHealth() = default;
    ~__DONOTUSE__ConnectionHealth() = default;

    EventMetric* changedToNoSignalGetter () { return &mozilla::glean::connection_health::changed_to_no_signal; };
    const EventMetric& changedToNoSignal () const { return mozilla::glean::connection_health::changed_to_no_signal; };
    EventMetric* changedToPendingGetter () { return &mozilla::glean::connection_health::changed_to_pending; };
    const EventMetric& changedToPending () const { return mozilla::glean::connection_health::changed_to_pending; };
    EventMetric* changedToStableGetter () { return &mozilla::glean::connection_health::changed_to_stable; };
    const EventMetric& changedToStable () const { return mozilla::glean::connection_health::changed_to_stable; };
    EventMetric* changedToUnstableGetter () { return &mozilla::glean::connection_health::changed_to_unstable; };
    const EventMetric& changedToUnstable () const { return mozilla::glean::connection_health::changed_to_unstable; };
    CustomDistributionMetric* dataTransferredRxGetter () { return &mozilla::glean::connection_health::data_transferred_rx; };
    const CustomDistributionMetric& dataTransferredRx () const { return mozilla::glean::connection_health::data_transferred_rx; };
    CustomDistributionMetric* dataTransferredTxGetter () { return &mozilla::glean::connection_health::data_transferred_tx; };
    const CustomDistributionMetric& dataTransferredTx () const { return mozilla::glean::connection_health::data_transferred_tx; };
    CounterMetric* noSignalCountGetter () { return &mozilla::glean::connection_health::no_signal_count; };
    const CounterMetric& noSignalCount () const { return mozilla::glean::connection_health::no_signal_count; };
    TimingDistributionMetric* noSignalTimeGetter () { return &mozilla::glean::connection_health::no_signal_time; };
    const TimingDistributionMetric& noSignalTime () const { return mozilla::glean::connection_health::no_signal_time; };
    CounterMetric* pendingCountGetter () { return &mozilla::glean::connection_health::pending_count; };
    const CounterMetric& pendingCount () const { return mozilla::glean::connection_health::pending_count; };
    TimingDistributionMetric* pendingTimeGetter () { return &mozilla::glean::connection_health::pending_time; };
    const TimingDistributionMetric& pendingTime () const { return mozilla::glean::connection_health::pending_time; };
    EventMetric* pingAnalyzerErrorGetter () { return &mozilla::glean::connection_health::ping_analyzer_error; };
    const EventMetric& pingAnalyzerError () const { return mozilla::glean::connection_health::ping_analyzer_error; };
    CounterMetric* stableCountGetter () { return &mozilla::glean::connection_health::stable_count; };
    const CounterMetric& stableCount () const { return mozilla::glean::connection_health::stable_count; };
    TimingDistributionMetric* stableTimeGetter () { return &mozilla::glean::connection_health::stable_time; };
    const TimingDistributionMetric& stableTime () const { return mozilla::glean::connection_health::stable_time; };
    CounterMetric* unstableCountGetter () { return &mozilla::glean::connection_health::unstable_count; };
    const CounterMetric& unstableCount () const { return mozilla::glean::connection_health::unstable_count; };
    TimingDistributionMetric* unstableTimeGetter () { return &mozilla::glean::connection_health::unstable_time; };
    const TimingDistributionMetric& unstableTime () const { return mozilla::glean::connection_health::unstable_time; };
};
class __DONOTUSE__Performance final : public QObject {
  Q_OBJECT

  Q_PROPERTY(TimingDistributionMetric* timeToMainScreen READ timeToMainScreenGetter CONSTANT);

  public:
    __DONOTUSE__Performance() = default;
    ~__DONOTUSE__Performance() = default;

    TimingDistributionMetric* timeToMainScreenGetter () { return &mozilla::glean::performance::time_to_main_screen; };
    const TimingDistributionMetric& timeToMainScreen () const { return mozilla::glean::performance::time_to_main_screen; };
};
class __DONOTUSE__Sample final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* addonMessageStateChanged READ addonMessageStateChangedGetter CONSTANT);
  Q_PROPERTY(EventMetric* authenticationError READ authenticationErrorGetter CONSTANT);
  Q_PROPERTY(EventMetric* authenticationFailure READ authenticationFailureGetter CONSTANT);
  Q_PROPERTY(EventMetric* authenticationFailureByGeo READ authenticationFailureByGeoGetter CONSTANT);
  Q_PROPERTY(EventMetric* bottomNavigationBarClick READ bottomNavigationBarClickGetter CONSTANT);
  Q_PROPERTY(EventMetric* deleteAccountClicked READ deleteAccountClickedGetter CONSTANT);
  Q_PROPERTY(EventMetric* deleteAccountRequested READ deleteAccountRequestedGetter CONSTANT);
  Q_PROPERTY(EventMetric* errorAlertShown READ errorAlertShownGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGBillingNotAvailable READ iapGBillingNotAvailableGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGLaunchbillingflowFailed READ iapGLaunchbillingflowFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGNoSkuDetails READ iapGNoSkuDetailsGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGPurchaseAckFailed READ iapGPurchaseAckFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGPurchasesUpdateIsNull READ iapGPurchasesUpdateIsNullGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGPurchasesUpdatedFailed READ iapGPurchasesUpdatedFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGQueryPurchasesFailed READ iapGQueryPurchasesFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGQuerySkuDetailsFailed READ iapGQuerySkuDetailsFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGSkuWithoutMonth READ iapGSkuWithoutMonthGetter CONSTANT);
  Q_PROPERTY(EventMetric* iapGUnexpectedPurchasestate READ iapGUnexpectedPurchasestateGetter CONSTANT);
  Q_PROPERTY(EventMetric* userChangedEndpointGeo READ userChangedEndpointGeoGetter CONSTANT);

  public:
    __DONOTUSE__Sample() = default;
    ~__DONOTUSE__Sample() = default;

    EventMetric* addonMessageStateChangedGetter () { return &mozilla::glean::sample::addon_message_state_changed; };
    const EventMetric& addonMessageStateChanged () const { return mozilla::glean::sample::addon_message_state_changed; };
    EventMetric* authenticationErrorGetter () { return &mozilla::glean::sample::authentication_error; };
    const EventMetric& authenticationError () const { return mozilla::glean::sample::authentication_error; };
    EventMetric* authenticationFailureGetter () { return &mozilla::glean::sample::authentication_failure; };
    const EventMetric& authenticationFailure () const { return mozilla::glean::sample::authentication_failure; };
    EventMetric* authenticationFailureByGeoGetter () { return &mozilla::glean::sample::authentication_failure_by_geo; };
    const EventMetric& authenticationFailureByGeo () const { return mozilla::glean::sample::authentication_failure_by_geo; };
    EventMetric* bottomNavigationBarClickGetter () { return &mozilla::glean::sample::bottom_navigation_bar_click; };
    const EventMetric& bottomNavigationBarClick () const { return mozilla::glean::sample::bottom_navigation_bar_click; };
    EventMetric* deleteAccountClickedGetter () { return &mozilla::glean::sample::delete_account_clicked; };
    const EventMetric& deleteAccountClicked () const { return mozilla::glean::sample::delete_account_clicked; };
    EventMetric* deleteAccountRequestedGetter () { return &mozilla::glean::sample::delete_account_requested; };
    const EventMetric& deleteAccountRequested () const { return mozilla::glean::sample::delete_account_requested; };
    EventMetric* errorAlertShownGetter () { return &mozilla::glean::sample::error_alert_shown; };
    const EventMetric& errorAlertShown () const { return mozilla::glean::sample::error_alert_shown; };
    EventMetric* iapGBillingNotAvailableGetter () { return &mozilla::glean::sample::iap_g_billing_not_available; };
    const EventMetric& iapGBillingNotAvailable () const { return mozilla::glean::sample::iap_g_billing_not_available; };
    EventMetric* iapGLaunchbillingflowFailedGetter () { return &mozilla::glean::sample::iap_g_launchbillingflow_failed; };
    const EventMetric& iapGLaunchbillingflowFailed () const { return mozilla::glean::sample::iap_g_launchbillingflow_failed; };
    EventMetric* iapGNoSkuDetailsGetter () { return &mozilla::glean::sample::iap_g_no_sku_details; };
    const EventMetric& iapGNoSkuDetails () const { return mozilla::glean::sample::iap_g_no_sku_details; };
    EventMetric* iapGPurchaseAckFailedGetter () { return &mozilla::glean::sample::iap_g_purchase_ack_failed; };
    const EventMetric& iapGPurchaseAckFailed () const { return mozilla::glean::sample::iap_g_purchase_ack_failed; };
    EventMetric* iapGPurchasesUpdateIsNullGetter () { return &mozilla::glean::sample::iap_g_purchases_update_is_null; };
    const EventMetric& iapGPurchasesUpdateIsNull () const { return mozilla::glean::sample::iap_g_purchases_update_is_null; };
    EventMetric* iapGPurchasesUpdatedFailedGetter () { return &mozilla::glean::sample::iap_g_purchases_updated_failed; };
    const EventMetric& iapGPurchasesUpdatedFailed () const { return mozilla::glean::sample::iap_g_purchases_updated_failed; };
    EventMetric* iapGQueryPurchasesFailedGetter () { return &mozilla::glean::sample::iap_g_query_purchases_failed; };
    const EventMetric& iapGQueryPurchasesFailed () const { return mozilla::glean::sample::iap_g_query_purchases_failed; };
    EventMetric* iapGQuerySkuDetailsFailedGetter () { return &mozilla::glean::sample::iap_g_query_sku_details_failed; };
    const EventMetric& iapGQuerySkuDetailsFailed () const { return mozilla::glean::sample::iap_g_query_sku_details_failed; };
    EventMetric* iapGSkuWithoutMonthGetter () { return &mozilla::glean::sample::iap_g_sku_without_month; };
    const EventMetric& iapGSkuWithoutMonth () const { return mozilla::glean::sample::iap_g_sku_without_month; };
    EventMetric* iapGUnexpectedPurchasestateGetter () { return &mozilla::glean::sample::iap_g_unexpected_purchasestate; };
    const EventMetric& iapGUnexpectedPurchasestate () const { return mozilla::glean::sample::iap_g_unexpected_purchasestate; };
    EventMetric* userChangedEndpointGeoGetter () { return &mozilla::glean::sample::user_changed_endpoint_geo; };
    const EventMetric& userChangedEndpointGeo () const { return mozilla::glean::sample::user_changed_endpoint_geo; };
};
class __DONOTUSE__Session final : public QObject {
  Q_OBJECT

  Q_PROPERTY(QuantityMetric* appsExcluded READ appsExcludedGetter CONSTANT);
  Q_PROPERTY(DatetimeMetric* daemonSessionEnd READ daemonSessionEndGetter CONSTANT);
  Q_PROPERTY(UuidMetric* daemonSessionId READ daemonSessionIdGetter CONSTANT);
  Q_PROPERTY(StringMetric* daemonSessionSource READ daemonSessionSourceGetter CONSTANT);
  Q_PROPERTY(DatetimeMetric* daemonSessionStart READ daemonSessionStartGetter CONSTANT);
  Q_PROPERTY(EventMetric* daemonSilentServerSwitch READ daemonSilentServerSwitchGetter CONSTANT);
  Q_PROPERTY(StringMetric* dnsType READ dnsTypeGetter CONSTANT);
  Q_PROPERTY(UuidMetric* installationId READ installationIdGetter CONSTANT);
  Q_PROPERTY(DatetimeMetric* sessionEnd READ sessionEndGetter CONSTANT);
  Q_PROPERTY(UuidMetric* sessionId READ sessionIdGetter CONSTANT);
  Q_PROPERTY(DatetimeMetric* sessionStart READ sessionStartGetter CONSTANT);

  public:
    __DONOTUSE__Session() = default;
    ~__DONOTUSE__Session() = default;

    QuantityMetric* appsExcludedGetter () { return &mozilla::glean::session::apps_excluded; };
    const QuantityMetric& appsExcluded () const { return mozilla::glean::session::apps_excluded; };
    DatetimeMetric* daemonSessionEndGetter () { return &mozilla::glean::session::daemon_session_end; };
    const DatetimeMetric& daemonSessionEnd () const { return mozilla::glean::session::daemon_session_end; };
    UuidMetric* daemonSessionIdGetter () { return &mozilla::glean::session::daemon_session_id; };
    const UuidMetric& daemonSessionId () const { return mozilla::glean::session::daemon_session_id; };
    StringMetric* daemonSessionSourceGetter () { return &mozilla::glean::session::daemon_session_source; };
    const StringMetric& daemonSessionSource () const { return mozilla::glean::session::daemon_session_source; };
    DatetimeMetric* daemonSessionStartGetter () { return &mozilla::glean::session::daemon_session_start; };
    const DatetimeMetric& daemonSessionStart () const { return mozilla::glean::session::daemon_session_start; };
    EventMetric* daemonSilentServerSwitchGetter () { return &mozilla::glean::session::daemon_silent_server_switch; };
    const EventMetric& daemonSilentServerSwitch () const { return mozilla::glean::session::daemon_silent_server_switch; };
    StringMetric* dnsTypeGetter () { return &mozilla::glean::session::dns_type; };
    const StringMetric& dnsType () const { return mozilla::glean::session::dns_type; };
    UuidMetric* installationIdGetter () { return &mozilla::glean::session::installation_id; };
    const UuidMetric& installationId () const { return mozilla::glean::session::installation_id; };
    DatetimeMetric* sessionEndGetter () { return &mozilla::glean::session::session_end; };
    const DatetimeMetric& sessionEnd () const { return mozilla::glean::session::session_end; };
    UuidMetric* sessionIdGetter () { return &mozilla::glean::session::session_id; };
    const UuidMetric& sessionId () const { return mozilla::glean::session::session_id; };
    DatetimeMetric* sessionStartGetter () { return &mozilla::glean::session::session_start; };
    const DatetimeMetric& sessionStart () const { return mozilla::glean::session::session_start; };
};
class __DONOTUSE__Settings final : public QObject {
  Q_OBJECT

  Q_PROPERTY(BooleanMetric* connectOnStartupActive READ connectOnStartupActiveGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* usingSystemLanguage READ usingSystemLanguageGetter CONSTANT);

  public:
    __DONOTUSE__Settings() = default;
    ~__DONOTUSE__Settings() = default;

    BooleanMetric* connectOnStartupActiveGetter () { return &mozilla::glean::settings::connect_on_startup_active; };
    const BooleanMetric& connectOnStartupActive () const { return mozilla::glean::settings::connect_on_startup_active; };
    BooleanMetric* usingSystemLanguageGetter () { return &mozilla::glean::settings::using_system_language; };
    const BooleanMetric& usingSystemLanguage () const { return mozilla::glean::settings::using_system_language; };
};
class __DONOTUSE__WebAuthentication final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* failed READ failedGetter CONSTANT);
  Q_PROPERTY(EventMetric* started READ startedGetter CONSTANT);
  Q_PROPERTY(EventMetric* successful READ successfulGetter CONSTANT);

  public:
    __DONOTUSE__WebAuthentication() = default;
    ~__DONOTUSE__WebAuthentication() = default;

    EventMetric* failedGetter () { return &mozilla::glean::web_authentication::failed; };
    const EventMetric& failed () const { return mozilla::glean::web_authentication::failed; };
    EventMetric* startedGetter () { return &mozilla::glean::web_authentication::started; };
    const EventMetric& started () const { return mozilla::glean::web_authentication::started; };
    EventMetric* successfulGetter () { return &mozilla::glean::web_authentication::successful; };
    const EventMetric& successful () const { return mozilla::glean::web_authentication::successful; };
};
class __DONOTUSE__Extension final : public QObject {
  Q_OBJECT

  Q_PROPERTY(QuantityMetric* countExcluded READ countExcludedGetter CONSTANT);
  Q_PROPERTY(QuantityMetric* countGeoprefed READ countGeoprefedGetter CONSTANT);
  Q_PROPERTY(EventMetric* errorScreen READ errorScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* fxProtectionDisabled READ fxProtectionDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* fxProtectionEnabled READ fxProtectionEnabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* fxProtectionModeChanged READ fxProtectionModeChangedGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* hasCompletedOnboarding READ hasCompletedOnboardingGetter CONSTANT);
  Q_PROPERTY(EventMetric* mainScreen READ mainScreenGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* usedFeatureDisableFirefoxProtection READ usedFeatureDisableFirefoxProtectionGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* usedFeaturePageActionRevokeExclude READ usedFeaturePageActionRevokeExcludeGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* usedFeaturePageActionRevokeGeopref READ usedFeaturePageActionRevokeGeoprefGetter CONSTANT);
  Q_PROPERTY(BooleanMetric* usedFeatureSettingsPage READ usedFeatureSettingsPageGetter CONSTANT);

  public:
    __DONOTUSE__Extension() = default;
    ~__DONOTUSE__Extension() = default;

    QuantityMetric* countExcludedGetter () { return &mozilla::glean::extension::count_excluded; };
    const QuantityMetric& countExcluded () const { return mozilla::glean::extension::count_excluded; };
    QuantityMetric* countGeoprefedGetter () { return &mozilla::glean::extension::count_geoprefed; };
    const QuantityMetric& countGeoprefed () const { return mozilla::glean::extension::count_geoprefed; };
    EventMetric* errorScreenGetter () { return &mozilla::glean::extension::error_screen; };
    const EventMetric& errorScreen () const { return mozilla::glean::extension::error_screen; };
    EventMetric* fxProtectionDisabledGetter () { return &mozilla::glean::extension::fx_protection_disabled; };
    const EventMetric& fxProtectionDisabled () const { return mozilla::glean::extension::fx_protection_disabled; };
    EventMetric* fxProtectionEnabledGetter () { return &mozilla::glean::extension::fx_protection_enabled; };
    const EventMetric& fxProtectionEnabled () const { return mozilla::glean::extension::fx_protection_enabled; };
    EventMetric* fxProtectionModeChangedGetter () { return &mozilla::glean::extension::fx_protection_mode_changed; };
    const EventMetric& fxProtectionModeChanged () const { return mozilla::glean::extension::fx_protection_mode_changed; };
    BooleanMetric* hasCompletedOnboardingGetter () { return &mozilla::glean::extension::has_completed_onboarding; };
    const BooleanMetric& hasCompletedOnboarding () const { return mozilla::glean::extension::has_completed_onboarding; };
    EventMetric* mainScreenGetter () { return &mozilla::glean::extension::main_screen; };
    const EventMetric& mainScreen () const { return mozilla::glean::extension::main_screen; };
    BooleanMetric* usedFeatureDisableFirefoxProtectionGetter () { return &mozilla::glean::extension::used_feature_disable_firefox_protection; };
    const BooleanMetric& usedFeatureDisableFirefoxProtection () const { return mozilla::glean::extension::used_feature_disable_firefox_protection; };
    BooleanMetric* usedFeaturePageActionRevokeExcludeGetter () { return &mozilla::glean::extension::used_feature_page_action_revoke_exclude; };
    const BooleanMetric& usedFeaturePageActionRevokeExclude () const { return mozilla::glean::extension::used_feature_page_action_revoke_exclude; };
    BooleanMetric* usedFeaturePageActionRevokeGeoprefGetter () { return &mozilla::glean::extension::used_feature_page_action_revoke_geopref; };
    const BooleanMetric& usedFeaturePageActionRevokeGeopref () const { return mozilla::glean::extension::used_feature_page_action_revoke_geopref; };
    BooleanMetric* usedFeatureSettingsPageGetter () { return &mozilla::glean::extension::used_feature_settings_page; };
    const BooleanMetric& usedFeatureSettingsPage () const { return mozilla::glean::extension::used_feature_settings_page; };
};
class __DONOTUSE__Interaction final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* aboutUsSelected READ aboutUsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* accountSelected READ accountSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* addApplicationSelected READ addApplicationSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* addDevicesSelected READ addDevicesSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* alreadyASubscriberSelected READ alreadyASubscriberSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* appExclusionsSelected READ appExclusionsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* appPreferencesSelected READ appPreferencesSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* approveMozillaVpnSelected READ approveMozillaVpnSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* backSelected READ backSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockAdsDisabled READ blockAdsDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockAdsEnabled READ blockAdsEnabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockMalwareDisabled READ blockMalwareDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockMalwareEnabled READ blockMalwareEnabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockTrackersDisabled READ blockTrackersDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* blockTrackersEnabled READ blockTrackersEnabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* cancelSelected READ cancelSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* changeEmailSelected READ changeEmailSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* changePlanSelected READ changePlanSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* clearAppExclusionsSelected READ clearAppExclusionsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* closeSelected READ closeSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* connectOnStartupDisabled READ connectOnStartupDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* connectOnStartupEnabled READ connectOnStartupEnabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* continueSelected READ continueSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* createAccountSelected READ createAccountSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* dataUseSelected READ dataUseSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* dnsSettingsSelected READ dnsSettingsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* editSelected READ editSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* forgotYourPasswordSelected READ forgotYourPasswordSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* getHelpSelected READ getHelpSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* getStartedSelected READ getStartedSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* goBackSelected READ goBackSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* helpTooltipSelected READ helpTooltipSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* homeSelected READ homeSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* languageSelected READ languageSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* learnMoreSelected READ learnMoreSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* manageSubscriptionSelected READ manageSubscriptionSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* messagesSelected READ messagesSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* morePrivacySelected READ morePrivacySelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* myDevicesSelected READ myDevicesSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* notificationsSelected READ notificationsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* openConnectionInfoSelected READ openConnectionInfoSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* pastePasswordSelected READ pastePasswordSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* privacyFeaturesSelected READ privacyFeaturesSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* privacyNoticeSelected READ privacyNoticeSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* resendCodeSelected READ resendCodeSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* resetVpnSelected READ resetVpnSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* searchSelected READ searchSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* settingsSelected READ settingsSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* showAndroidQrSelected READ showAndroidQrSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* showIosQrSelected READ showIosQrSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* signInSelected READ signInSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* signOutSelected READ signOutSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* signupSelected READ signupSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* subscribeNowSelected READ subscribeNowSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* termsOfServiceSelected READ termsOfServiceSelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* verifySelected READ verifySelectedGetter CONSTANT);
  Q_PROPERTY(EventMetric* vpnOnStartupDisabled READ vpnOnStartupDisabledGetter CONSTANT);
  Q_PROPERTY(EventMetric* vpnOnStartupEnabled READ vpnOnStartupEnabledGetter CONSTANT);

  public:
    __DONOTUSE__Interaction() = default;
    ~__DONOTUSE__Interaction() = default;

    EventMetric* aboutUsSelectedGetter () { return &mozilla::glean::interaction::about_us_selected; };
    const EventMetric& aboutUsSelected () const { return mozilla::glean::interaction::about_us_selected; };
    EventMetric* accountSelectedGetter () { return &mozilla::glean::interaction::account_selected; };
    const EventMetric& accountSelected () const { return mozilla::glean::interaction::account_selected; };
    EventMetric* addApplicationSelectedGetter () { return &mozilla::glean::interaction::add_application_selected; };
    const EventMetric& addApplicationSelected () const { return mozilla::glean::interaction::add_application_selected; };
    EventMetric* addDevicesSelectedGetter () { return &mozilla::glean::interaction::add_devices_selected; };
    const EventMetric& addDevicesSelected () const { return mozilla::glean::interaction::add_devices_selected; };
    EventMetric* alreadyASubscriberSelectedGetter () { return &mozilla::glean::interaction::already_a_subscriber_selected; };
    const EventMetric& alreadyASubscriberSelected () const { return mozilla::glean::interaction::already_a_subscriber_selected; };
    EventMetric* appExclusionsSelectedGetter () { return &mozilla::glean::interaction::app_exclusions_selected; };
    const EventMetric& appExclusionsSelected () const { return mozilla::glean::interaction::app_exclusions_selected; };
    EventMetric* appPreferencesSelectedGetter () { return &mozilla::glean::interaction::app_preferences_selected; };
    const EventMetric& appPreferencesSelected () const { return mozilla::glean::interaction::app_preferences_selected; };
    EventMetric* approveMozillaVpnSelectedGetter () { return &mozilla::glean::interaction::approve_mozilla_vpn_selected; };
    const EventMetric& approveMozillaVpnSelected () const { return mozilla::glean::interaction::approve_mozilla_vpn_selected; };
    EventMetric* backSelectedGetter () { return &mozilla::glean::interaction::back_selected; };
    const EventMetric& backSelected () const { return mozilla::glean::interaction::back_selected; };
    EventMetric* blockAdsDisabledGetter () { return &mozilla::glean::interaction::block_ads_disabled; };
    const EventMetric& blockAdsDisabled () const { return mozilla::glean::interaction::block_ads_disabled; };
    EventMetric* blockAdsEnabledGetter () { return &mozilla::glean::interaction::block_ads_enabled; };
    const EventMetric& blockAdsEnabled () const { return mozilla::glean::interaction::block_ads_enabled; };
    EventMetric* blockMalwareDisabledGetter () { return &mozilla::glean::interaction::block_malware_disabled; };
    const EventMetric& blockMalwareDisabled () const { return mozilla::glean::interaction::block_malware_disabled; };
    EventMetric* blockMalwareEnabledGetter () { return &mozilla::glean::interaction::block_malware_enabled; };
    const EventMetric& blockMalwareEnabled () const { return mozilla::glean::interaction::block_malware_enabled; };
    EventMetric* blockTrackersDisabledGetter () { return &mozilla::glean::interaction::block_trackers_disabled; };
    const EventMetric& blockTrackersDisabled () const { return mozilla::glean::interaction::block_trackers_disabled; };
    EventMetric* blockTrackersEnabledGetter () { return &mozilla::glean::interaction::block_trackers_enabled; };
    const EventMetric& blockTrackersEnabled () const { return mozilla::glean::interaction::block_trackers_enabled; };
    EventMetric* cancelSelectedGetter () { return &mozilla::glean::interaction::cancel_selected; };
    const EventMetric& cancelSelected () const { return mozilla::glean::interaction::cancel_selected; };
    EventMetric* changeEmailSelectedGetter () { return &mozilla::glean::interaction::change_email_selected; };
    const EventMetric& changeEmailSelected () const { return mozilla::glean::interaction::change_email_selected; };
    EventMetric* changePlanSelectedGetter () { return &mozilla::glean::interaction::change_plan_selected; };
    const EventMetric& changePlanSelected () const { return mozilla::glean::interaction::change_plan_selected; };
    EventMetric* clearAppExclusionsSelectedGetter () { return &mozilla::glean::interaction::clear_app_exclusions_selected; };
    const EventMetric& clearAppExclusionsSelected () const { return mozilla::glean::interaction::clear_app_exclusions_selected; };
    EventMetric* closeSelectedGetter () { return &mozilla::glean::interaction::close_selected; };
    const EventMetric& closeSelected () const { return mozilla::glean::interaction::close_selected; };
    EventMetric* connectOnStartupDisabledGetter () { return &mozilla::glean::interaction::connect_on_startup_disabled; };
    const EventMetric& connectOnStartupDisabled () const { return mozilla::glean::interaction::connect_on_startup_disabled; };
    EventMetric* connectOnStartupEnabledGetter () { return &mozilla::glean::interaction::connect_on_startup_enabled; };
    const EventMetric& connectOnStartupEnabled () const { return mozilla::glean::interaction::connect_on_startup_enabled; };
    EventMetric* continueSelectedGetter () { return &mozilla::glean::interaction::continue_selected; };
    const EventMetric& continueSelected () const { return mozilla::glean::interaction::continue_selected; };
    EventMetric* createAccountSelectedGetter () { return &mozilla::glean::interaction::create_account_selected; };
    const EventMetric& createAccountSelected () const { return mozilla::glean::interaction::create_account_selected; };
    EventMetric* dataUseSelectedGetter () { return &mozilla::glean::interaction::data_use_selected; };
    const EventMetric& dataUseSelected () const { return mozilla::glean::interaction::data_use_selected; };
    EventMetric* dnsSettingsSelectedGetter () { return &mozilla::glean::interaction::dns_settings_selected; };
    const EventMetric& dnsSettingsSelected () const { return mozilla::glean::interaction::dns_settings_selected; };
    EventMetric* editSelectedGetter () { return &mozilla::glean::interaction::edit_selected; };
    const EventMetric& editSelected () const { return mozilla::glean::interaction::edit_selected; };
    EventMetric* forgotYourPasswordSelectedGetter () { return &mozilla::glean::interaction::forgot_your_password_selected; };
    const EventMetric& forgotYourPasswordSelected () const { return mozilla::glean::interaction::forgot_your_password_selected; };
    EventMetric* getHelpSelectedGetter () { return &mozilla::glean::interaction::get_help_selected; };
    const EventMetric& getHelpSelected () const { return mozilla::glean::interaction::get_help_selected; };
    EventMetric* getStartedSelectedGetter () { return &mozilla::glean::interaction::get_started_selected; };
    const EventMetric& getStartedSelected () const { return mozilla::glean::interaction::get_started_selected; };
    EventMetric* goBackSelectedGetter () { return &mozilla::glean::interaction::go_back_selected; };
    const EventMetric& goBackSelected () const { return mozilla::glean::interaction::go_back_selected; };
    EventMetric* helpTooltipSelectedGetter () { return &mozilla::glean::interaction::help_tooltip_selected; };
    const EventMetric& helpTooltipSelected () const { return mozilla::glean::interaction::help_tooltip_selected; };
    EventMetric* homeSelectedGetter () { return &mozilla::glean::interaction::home_selected; };
    const EventMetric& homeSelected () const { return mozilla::glean::interaction::home_selected; };
    EventMetric* languageSelectedGetter () { return &mozilla::glean::interaction::language_selected; };
    const EventMetric& languageSelected () const { return mozilla::glean::interaction::language_selected; };
    EventMetric* learnMoreSelectedGetter () { return &mozilla::glean::interaction::learn_more_selected; };
    const EventMetric& learnMoreSelected () const { return mozilla::glean::interaction::learn_more_selected; };
    EventMetric* manageSubscriptionSelectedGetter () { return &mozilla::glean::interaction::manage_subscription_selected; };
    const EventMetric& manageSubscriptionSelected () const { return mozilla::glean::interaction::manage_subscription_selected; };
    EventMetric* messagesSelectedGetter () { return &mozilla::glean::interaction::messages_selected; };
    const EventMetric& messagesSelected () const { return mozilla::glean::interaction::messages_selected; };
    EventMetric* morePrivacySelectedGetter () { return &mozilla::glean::interaction::more_privacy_selected; };
    const EventMetric& morePrivacySelected () const { return mozilla::glean::interaction::more_privacy_selected; };
    EventMetric* myDevicesSelectedGetter () { return &mozilla::glean::interaction::my_devices_selected; };
    const EventMetric& myDevicesSelected () const { return mozilla::glean::interaction::my_devices_selected; };
    EventMetric* notificationsSelectedGetter () { return &mozilla::glean::interaction::notifications_selected; };
    const EventMetric& notificationsSelected () const { return mozilla::glean::interaction::notifications_selected; };
    EventMetric* openConnectionInfoSelectedGetter () { return &mozilla::glean::interaction::open_connection_info_selected; };
    const EventMetric& openConnectionInfoSelected () const { return mozilla::glean::interaction::open_connection_info_selected; };
    EventMetric* pastePasswordSelectedGetter () { return &mozilla::glean::interaction::paste_password_selected; };
    const EventMetric& pastePasswordSelected () const { return mozilla::glean::interaction::paste_password_selected; };
    EventMetric* privacyFeaturesSelectedGetter () { return &mozilla::glean::interaction::privacy_features_selected; };
    const EventMetric& privacyFeaturesSelected () const { return mozilla::glean::interaction::privacy_features_selected; };
    EventMetric* privacyNoticeSelectedGetter () { return &mozilla::glean::interaction::privacy_notice_selected; };
    const EventMetric& privacyNoticeSelected () const { return mozilla::glean::interaction::privacy_notice_selected; };
    EventMetric* resendCodeSelectedGetter () { return &mozilla::glean::interaction::resend_code_selected; };
    const EventMetric& resendCodeSelected () const { return mozilla::glean::interaction::resend_code_selected; };
    EventMetric* resetVpnSelectedGetter () { return &mozilla::glean::interaction::reset_vpn_selected; };
    const EventMetric& resetVpnSelected () const { return mozilla::glean::interaction::reset_vpn_selected; };
    EventMetric* searchSelectedGetter () { return &mozilla::glean::interaction::search_selected; };
    const EventMetric& searchSelected () const { return mozilla::glean::interaction::search_selected; };
    EventMetric* settingsSelectedGetter () { return &mozilla::glean::interaction::settings_selected; };
    const EventMetric& settingsSelected () const { return mozilla::glean::interaction::settings_selected; };
    EventMetric* showAndroidQrSelectedGetter () { return &mozilla::glean::interaction::show_android_qr_selected; };
    const EventMetric& showAndroidQrSelected () const { return mozilla::glean::interaction::show_android_qr_selected; };
    EventMetric* showIosQrSelectedGetter () { return &mozilla::glean::interaction::show_ios_qr_selected; };
    const EventMetric& showIosQrSelected () const { return mozilla::glean::interaction::show_ios_qr_selected; };
    EventMetric* signInSelectedGetter () { return &mozilla::glean::interaction::sign_in_selected; };
    const EventMetric& signInSelected () const { return mozilla::glean::interaction::sign_in_selected; };
    EventMetric* signOutSelectedGetter () { return &mozilla::glean::interaction::sign_out_selected; };
    const EventMetric& signOutSelected () const { return mozilla::glean::interaction::sign_out_selected; };
    EventMetric* signupSelectedGetter () { return &mozilla::glean::interaction::signup_selected; };
    const EventMetric& signupSelected () const { return mozilla::glean::interaction::signup_selected; };
    EventMetric* subscribeNowSelectedGetter () { return &mozilla::glean::interaction::subscribe_now_selected; };
    const EventMetric& subscribeNowSelected () const { return mozilla::glean::interaction::subscribe_now_selected; };
    EventMetric* termsOfServiceSelectedGetter () { return &mozilla::glean::interaction::terms_of_service_selected; };
    const EventMetric& termsOfServiceSelected () const { return mozilla::glean::interaction::terms_of_service_selected; };
    EventMetric* verifySelectedGetter () { return &mozilla::glean::interaction::verify_selected; };
    const EventMetric& verifySelected () const { return mozilla::glean::interaction::verify_selected; };
    EventMetric* vpnOnStartupDisabledGetter () { return &mozilla::glean::interaction::vpn_on_startup_disabled; };
    const EventMetric& vpnOnStartupDisabled () const { return mozilla::glean::interaction::vpn_on_startup_disabled; };
    EventMetric* vpnOnStartupEnabledGetter () { return &mozilla::glean::interaction::vpn_on_startup_enabled; };
    const EventMetric& vpnOnStartupEnabled () const { return mozilla::glean::interaction::vpn_on_startup_enabled; };
};
class __DONOTUSE__Impression final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* accountScreen READ accountScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* appExclusionsInfoScreen READ appExclusionsInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* appExclusionsScreen READ appExclusionsScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* appPreferencesScreen READ appPreferencesScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* confirmingSubscriptionScreen READ confirmingSubscriptionScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* connectOnStartupScreen READ connectOnStartupScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* connectionInfoScreen READ connectionInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* continueInBrowserScreen READ continueInBrowserScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* createPasswordScreen READ createPasswordScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* dataCollectionScreen READ dataCollectionScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* dnsSettingsInfoScreen READ dnsSettingsInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* dnsSettingsScreen READ dnsSettingsScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* enterEmailScreen READ enterEmailScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* enterPasswordScreen READ enterPasswordScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* enterSecurityCodeScreen READ enterSecurityCodeScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* enterUnblockCodeScreen READ enterUnblockCodeScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* enterVerificationCodeScreen READ enterVerificationCodeScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* getMorePrivacyScreen READ getMorePrivacyScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* helpScreen READ helpScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* installOn5DevicesScreen READ installOn5DevicesScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* languageScreen READ languageScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* locationInfoScreen READ locationInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* locationMultihopScreen READ locationMultihopScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* locationSinglehopScreen READ locationSinglehopScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* mainScreen READ mainScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* myDevicesInfoScreen READ myDevicesInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* myDevicesScreen READ myDevicesScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* networkPermissionsScreen READ networkPermissionsScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* privacyFeaturesInfoScreen READ privacyFeaturesInfoScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* privacyFeaturesScreen READ privacyFeaturesScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* settingsScreen READ settingsScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* signupScreen READ signupScreenGetter CONSTANT);
  Q_PROPERTY(EventMetric* subscriptionNeededScreen READ subscriptionNeededScreenGetter CONSTANT);

  public:
    __DONOTUSE__Impression() = default;
    ~__DONOTUSE__Impression() = default;

    EventMetric* accountScreenGetter () { return &mozilla::glean::impression::account_screen; };
    const EventMetric& accountScreen () const { return mozilla::glean::impression::account_screen; };
    EventMetric* appExclusionsInfoScreenGetter () { return &mozilla::glean::impression::app_exclusions_info_screen; };
    const EventMetric& appExclusionsInfoScreen () const { return mozilla::glean::impression::app_exclusions_info_screen; };
    EventMetric* appExclusionsScreenGetter () { return &mozilla::glean::impression::app_exclusions_screen; };
    const EventMetric& appExclusionsScreen () const { return mozilla::glean::impression::app_exclusions_screen; };
    EventMetric* appPreferencesScreenGetter () { return &mozilla::glean::impression::app_preferences_screen; };
    const EventMetric& appPreferencesScreen () const { return mozilla::glean::impression::app_preferences_screen; };
    EventMetric* confirmingSubscriptionScreenGetter () { return &mozilla::glean::impression::confirming_subscription_screen; };
    const EventMetric& confirmingSubscriptionScreen () const { return mozilla::glean::impression::confirming_subscription_screen; };
    EventMetric* connectOnStartupScreenGetter () { return &mozilla::glean::impression::connect_on_startup_screen; };
    const EventMetric& connectOnStartupScreen () const { return mozilla::glean::impression::connect_on_startup_screen; };
    EventMetric* connectionInfoScreenGetter () { return &mozilla::glean::impression::connection_info_screen; };
    const EventMetric& connectionInfoScreen () const { return mozilla::glean::impression::connection_info_screen; };
    EventMetric* continueInBrowserScreenGetter () { return &mozilla::glean::impression::continue_in_browser_screen; };
    const EventMetric& continueInBrowserScreen () const { return mozilla::glean::impression::continue_in_browser_screen; };
    EventMetric* createPasswordScreenGetter () { return &mozilla::glean::impression::create_password_screen; };
    const EventMetric& createPasswordScreen () const { return mozilla::glean::impression::create_password_screen; };
    EventMetric* dataCollectionScreenGetter () { return &mozilla::glean::impression::data_collection_screen; };
    const EventMetric& dataCollectionScreen () const { return mozilla::glean::impression::data_collection_screen; };
    EventMetric* dnsSettingsInfoScreenGetter () { return &mozilla::glean::impression::dns_settings_info_screen; };
    const EventMetric& dnsSettingsInfoScreen () const { return mozilla::glean::impression::dns_settings_info_screen; };
    EventMetric* dnsSettingsScreenGetter () { return &mozilla::glean::impression::dns_settings_screen; };
    const EventMetric& dnsSettingsScreen () const { return mozilla::glean::impression::dns_settings_screen; };
    EventMetric* enterEmailScreenGetter () { return &mozilla::glean::impression::enter_email_screen; };
    const EventMetric& enterEmailScreen () const { return mozilla::glean::impression::enter_email_screen; };
    EventMetric* enterPasswordScreenGetter () { return &mozilla::glean::impression::enter_password_screen; };
    const EventMetric& enterPasswordScreen () const { return mozilla::glean::impression::enter_password_screen; };
    EventMetric* enterSecurityCodeScreenGetter () { return &mozilla::glean::impression::enter_security_code_screen; };
    const EventMetric& enterSecurityCodeScreen () const { return mozilla::glean::impression::enter_security_code_screen; };
    EventMetric* enterUnblockCodeScreenGetter () { return &mozilla::glean::impression::enter_unblock_code_screen; };
    const EventMetric& enterUnblockCodeScreen () const { return mozilla::glean::impression::enter_unblock_code_screen; };
    EventMetric* enterVerificationCodeScreenGetter () { return &mozilla::glean::impression::enter_verification_code_screen; };
    const EventMetric& enterVerificationCodeScreen () const { return mozilla::glean::impression::enter_verification_code_screen; };
    EventMetric* getMorePrivacyScreenGetter () { return &mozilla::glean::impression::get_more_privacy_screen; };
    const EventMetric& getMorePrivacyScreen () const { return mozilla::glean::impression::get_more_privacy_screen; };
    EventMetric* helpScreenGetter () { return &mozilla::glean::impression::help_screen; };
    const EventMetric& helpScreen () const { return mozilla::glean::impression::help_screen; };
    EventMetric* installOn5DevicesScreenGetter () { return &mozilla::glean::impression::install_on_5_devices_screen; };
    const EventMetric& installOn5DevicesScreen () const { return mozilla::glean::impression::install_on_5_devices_screen; };
    EventMetric* languageScreenGetter () { return &mozilla::glean::impression::language_screen; };
    const EventMetric& languageScreen () const { return mozilla::glean::impression::language_screen; };
    EventMetric* locationInfoScreenGetter () { return &mozilla::glean::impression::location_info_screen; };
    const EventMetric& locationInfoScreen () const { return mozilla::glean::impression::location_info_screen; };
    EventMetric* locationMultihopScreenGetter () { return &mozilla::glean::impression::location_multihop_screen; };
    const EventMetric& locationMultihopScreen () const { return mozilla::glean::impression::location_multihop_screen; };
    EventMetric* locationSinglehopScreenGetter () { return &mozilla::glean::impression::location_singlehop_screen; };
    const EventMetric& locationSinglehopScreen () const { return mozilla::glean::impression::location_singlehop_screen; };
    EventMetric* mainScreenGetter () { return &mozilla::glean::impression::main_screen; };
    const EventMetric& mainScreen () const { return mozilla::glean::impression::main_screen; };
    EventMetric* myDevicesInfoScreenGetter () { return &mozilla::glean::impression::my_devices_info_screen; };
    const EventMetric& myDevicesInfoScreen () const { return mozilla::glean::impression::my_devices_info_screen; };
    EventMetric* myDevicesScreenGetter () { return &mozilla::glean::impression::my_devices_screen; };
    const EventMetric& myDevicesScreen () const { return mozilla::glean::impression::my_devices_screen; };
    EventMetric* networkPermissionsScreenGetter () { return &mozilla::glean::impression::network_permissions_screen; };
    const EventMetric& networkPermissionsScreen () const { return mozilla::glean::impression::network_permissions_screen; };
    EventMetric* privacyFeaturesInfoScreenGetter () { return &mozilla::glean::impression::privacy_features_info_screen; };
    const EventMetric& privacyFeaturesInfoScreen () const { return mozilla::glean::impression::privacy_features_info_screen; };
    EventMetric* privacyFeaturesScreenGetter () { return &mozilla::glean::impression::privacy_features_screen; };
    const EventMetric& privacyFeaturesScreen () const { return mozilla::glean::impression::privacy_features_screen; };
    EventMetric* settingsScreenGetter () { return &mozilla::glean::impression::settings_screen; };
    const EventMetric& settingsScreen () const { return mozilla::glean::impression::settings_screen; };
    EventMetric* signupScreenGetter () { return &mozilla::glean::impression::signup_screen; };
    const EventMetric& signupScreen () const { return mozilla::glean::impression::signup_screen; };
    EventMetric* subscriptionNeededScreenGetter () { return &mozilla::glean::impression::subscription_needed_screen; };
    const EventMetric& subscriptionNeededScreen () const { return mozilla::glean::impression::subscription_needed_screen; };
};
class __DONOTUSE__Outcome final : public QObject {
  Q_OBJECT

  Q_PROPERTY(EventMetric* loginEnded READ loginEndedGetter CONSTANT);
  Q_PROPERTY(EventMetric* loginStarted READ loginStartedGetter CONSTANT);
  Q_PROPERTY(EventMetric* onboardingCompleted READ onboardingCompletedGetter CONSTANT);
  Q_PROPERTY(EventMetric* onboardingNtwrkPermDenied READ onboardingNtwrkPermDeniedGetter CONSTANT);
  Q_PROPERTY(EventMetric* onboardingNtwrkPermGranted READ onboardingNtwrkPermGrantedGetter CONSTANT);
  Q_PROPERTY(EventMetric* onboardingStarted READ onboardingStartedGetter CONSTANT);
  Q_PROPERTY(EventMetric* registrationCompleted READ registrationCompletedGetter CONSTANT);
  Q_PROPERTY(EventMetric* registrationStarted READ registrationStartedGetter CONSTANT);
  Q_PROPERTY(EventMetric* subscriptionCompleted READ subscriptionCompletedGetter CONSTANT);
  Q_PROPERTY(EventMetric* subscriptionFailed READ subscriptionFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* subscriptionStarted READ subscriptionStartedGetter CONSTANT);
  Q_PROPERTY(EventMetric* twoFaVerificationFailed READ twoFaVerificationFailedGetter CONSTANT);
  Q_PROPERTY(EventMetric* twoFaVerificationSucceeded READ twoFaVerificationSucceededGetter CONSTANT);

  public:
    __DONOTUSE__Outcome() = default;
    ~__DONOTUSE__Outcome() = default;

    EventMetric* loginEndedGetter () { return &mozilla::glean::outcome::login_ended; };
    const EventMetric& loginEnded () const { return mozilla::glean::outcome::login_ended; };
    EventMetric* loginStartedGetter () { return &mozilla::glean::outcome::login_started; };
    const EventMetric& loginStarted () const { return mozilla::glean::outcome::login_started; };
    EventMetric* onboardingCompletedGetter () { return &mozilla::glean::outcome::onboarding_completed; };
    const EventMetric& onboardingCompleted () const { return mozilla::glean::outcome::onboarding_completed; };
    EventMetric* onboardingNtwrkPermDeniedGetter () { return &mozilla::glean::outcome::onboarding_ntwrk_perm_denied; };
    const EventMetric& onboardingNtwrkPermDenied () const { return mozilla::glean::outcome::onboarding_ntwrk_perm_denied; };
    EventMetric* onboardingNtwrkPermGrantedGetter () { return &mozilla::glean::outcome::onboarding_ntwrk_perm_granted; };
    const EventMetric& onboardingNtwrkPermGranted () const { return mozilla::glean::outcome::onboarding_ntwrk_perm_granted; };
    EventMetric* onboardingStartedGetter () { return &mozilla::glean::outcome::onboarding_started; };
    const EventMetric& onboardingStarted () const { return mozilla::glean::outcome::onboarding_started; };
    EventMetric* registrationCompletedGetter () { return &mozilla::glean::outcome::registration_completed; };
    const EventMetric& registrationCompleted () const { return mozilla::glean::outcome::registration_completed; };
    EventMetric* registrationStartedGetter () { return &mozilla::glean::outcome::registration_started; };
    const EventMetric& registrationStarted () const { return mozilla::glean::outcome::registration_started; };
    EventMetric* subscriptionCompletedGetter () { return &mozilla::glean::outcome::subscription_completed; };
    const EventMetric& subscriptionCompleted () const { return mozilla::glean::outcome::subscription_completed; };
    EventMetric* subscriptionFailedGetter () { return &mozilla::glean::outcome::subscription_failed; };
    const EventMetric& subscriptionFailed () const { return mozilla::glean::outcome::subscription_failed; };
    EventMetric* subscriptionStartedGetter () { return &mozilla::glean::outcome::subscription_started; };
    const EventMetric& subscriptionStarted () const { return mozilla::glean::outcome::subscription_started; };
    EventMetric* twoFaVerificationFailedGetter () { return &mozilla::glean::outcome::two_fa_verification_failed; };
    const EventMetric& twoFaVerificationFailed () const { return mozilla::glean::outcome::two_fa_verification_failed; };
    EventMetric* twoFaVerificationSucceededGetter () { return &mozilla::glean::outcome::two_fa_verification_succeeded; };
    const EventMetric& twoFaVerificationSucceeded () const { return mozilla::glean::outcome::two_fa_verification_succeeded; };
};

// This class is not meant to be used directly.
// It is exposed as a singleton to QML.
//
// The reason for this is to keep consistency with the Glean API on m-c.
// On JavaScript pings are accessed through GleanMetrics.<MyMetric> and
// on C++ they are accessed through mozilla::glean_pings::<my_metric>.
class __DONOTUSE__GleanMetrics final : public QObject {
    Q_OBJECT
    Q_DISABLE_COPY_MOVE(__DONOTUSE__GleanMetrics)

    Q_PROPERTY(__DONOTUSE__ConnectionHealth* connectionHealth READ connectionHealthGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Performance* performance READ performanceGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Sample* sample READ sampleGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Session* session READ sessionGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Settings* settings READ settingsGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__WebAuthentication* webAuthentication READ webAuthenticationGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Extension* extension READ extensionGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Interaction* interaction READ interactionGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Impression* impression READ impressionGetter CONSTANT);
    Q_PROPERTY(__DONOTUSE__Outcome* outcome READ outcomeGetter CONSTANT);

    private:
        __DONOTUSE__GleanMetrics() = default;

    public:
        ~__DONOTUSE__GleanMetrics() = default;

        static __DONOTUSE__GleanMetrics* instance() {
            if (!s_instance) {
                s_instance = new __DONOTUSE__GleanMetrics();
            }

            return s_instance;
        }

        __DONOTUSE__ConnectionHealth* connectionHealthGetter () { return &m_connectionHealth; };
        const __DONOTUSE__ConnectionHealth& connectionHealth () const { return m_connectionHealth; };
        __DONOTUSE__Performance* performanceGetter () { return &m_performance; };
        const __DONOTUSE__Performance& performance () const { return m_performance; };
        __DONOTUSE__Sample* sampleGetter () { return &m_sample; };
        const __DONOTUSE__Sample& sample () const { return m_sample; };
        __DONOTUSE__Session* sessionGetter () { return &m_session; };
        const __DONOTUSE__Session& session () const { return m_session; };
        __DONOTUSE__Settings* settingsGetter () { return &m_settings; };
        const __DONOTUSE__Settings& settings () const { return m_settings; };
        __DONOTUSE__WebAuthentication* webAuthenticationGetter () { return &m_webAuthentication; };
        const __DONOTUSE__WebAuthentication& webAuthentication () const { return m_webAuthentication; };
        __DONOTUSE__Extension* extensionGetter () { return &m_extension; };
        const __DONOTUSE__Extension& extension () const { return m_extension; };
        __DONOTUSE__Interaction* interactionGetter () { return &m_interaction; };
        const __DONOTUSE__Interaction& interaction () const { return m_interaction; };
        __DONOTUSE__Impression* impressionGetter () { return &m_impression; };
        const __DONOTUSE__Impression& impression () const { return m_impression; };
        __DONOTUSE__Outcome* outcomeGetter () { return &m_outcome; };
        const __DONOTUSE__Outcome& outcome () const { return m_outcome; };

    private:
        __DONOTUSE__ConnectionHealth m_connectionHealth = __DONOTUSE__ConnectionHealth() ;
        __DONOTUSE__Performance m_performance = __DONOTUSE__Performance() ;
        __DONOTUSE__Sample m_sample = __DONOTUSE__Sample() ;
        __DONOTUSE__Session m_session = __DONOTUSE__Session() ;
        __DONOTUSE__Settings m_settings = __DONOTUSE__Settings() ;
        __DONOTUSE__WebAuthentication m_webAuthentication = __DONOTUSE__WebAuthentication() ;
        __DONOTUSE__Extension m_extension = __DONOTUSE__Extension() ;
        __DONOTUSE__Interaction m_interaction = __DONOTUSE__Interaction() ;
        __DONOTUSE__Impression m_impression = __DONOTUSE__Impression() ;
        __DONOTUSE__Outcome m_outcome = __DONOTUSE__Outcome() ;

        inline static __DONOTUSE__GleanMetrics* s_instance = nullptr;
};

#endif // mozilla_Metrics_h
